bayespy.inference.vmp.nodes.node.Node
=====================================

.. currentmodule:: bayespy.inference.vmp.nodes.node

.. autoclass:: Node

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
      :toctree: generated/
   
      ~Node.__init__
      ~Node.add_plate_axis
      ~Node.broadcasting_multiplier
      ~Node.delete
      ~Node.get_mask
      ~Node.get_moments
      ~Node.get_shape
      ~Node.has_plotter
      ~Node.move_plates
      ~Node.plot
      ~Node.set_plotter
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
      :toctree: generated/
   
      ~Node.plates
      ~Node.plates_multiplier
   
   